==> qtjambi-uic-6.5.1-sources.jar: io/qt/uic/ui4/DomSlots.java <==
package io.qt.uic.ui4;

import io.qt.*;


/**
 * <p>Java wrapper for Qt class DomSlots</p>
 */
public class DomSlots extends QtObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    public DomSlots(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(DomSlots instance);
    
    @QtUninvokable
    public final io.qt.core.@NonNull QStringList elementSignal(){
        return elementSignal_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QStringList elementSignal_native_constfct(long __this__nativeId);
    
    @QtUninvokable
    public final io.qt.core.@NonNull QStringList elementSlot(){
        return elementSlot_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QStringList elementSlot_native_constfct(long __this__nativeId);
    
    @QtUninvokable
    public final void read(io.qt.core.@StrictNonNull QXmlStreamReader reader){
        java.util.Objects.requireNonNull(reader, "Argument 'reader': null not expected.");
        read_native_ref_QXmlStreamReader(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(reader));
    }
    
    @QtUninvokable
    private native void read_native_ref_QXmlStreamReader(long __this__nativeId, long reader);
    
    @QtUninvokable
    public final void setElementSignal(java.util.@NonNull Collection<java.lang.@NonNull String> a){
        setElementSignal_native_cref_QStringList(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @QtUninvokable
    private native void setElementSignal_native_cref_QStringList(long __this__nativeId, java.util.Collection<java.lang.String> a);
    
    @QtUninvokable
    public final void setElementSlot(java.util.@NonNull Collection<java.lang.@NonNull String> a){
        setElementSlot_native_cref_QStringList(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @QtUninvokable
    private native void setElementSlot_native_cref_QStringList(long __this__nativeId, java.util.Collection<java.lang.String> a);
    
    /**
     * <p>Overloaded function for {@link #write(io.qt.core.QXmlStreamWriter, java.lang.String)}
     *  with <code>tagName = (String)null</code>.</p>
     */
    @QtUninvokable
    public final void write(io.qt.core.@StrictNonNull QXmlStreamWriter writer) {
        write(writer, (String)null);
    }
    
    @QtUninvokable
    public final void write(io.qt.core.@StrictNonNull QXmlStreamWriter writer, java.lang.@NonNull String tagName){
        java.util.Objects.requireNonNull(writer, "Argument 'writer': null not expected.");
        write_native_ref_QXmlStreamWriter_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(writer), tagName);
    }
    
    @QtUninvokable
    private native void write_native_ref_QXmlStreamWriter_cref_QString_constfct(long __this__nativeId, long writer, java.lang.String tagName);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected DomSlots(QPrivateConstructor p) { super(p); } 
    
}

==> qtjambi-uic-6.6.2-sources.jar: io/qt/uic/ui4/DomSlots.java <==
package io.qt.uic.ui4;

import io.qt.*;


/**
 * @hidden
 * <p>Java wrapper for Qt class <code>DomSlots</code></p>
 */
public class DomSlots extends QtObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <code>DomSlots::<wbr/>DomSlots()</code></p>
     */
    public DomSlots(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(DomSlots instance);
    
    /**
     * <p>See <code>DomSlots::<wbr/>elementSignal()const</code></p>
     */
    @QtUninvokable
    public final io.qt.core.@NonNull QStringList elementSignal(){
        return elementSignal_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QStringList elementSignal_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomSlots::<wbr/>elementSlot()const</code></p>
     */
    @QtUninvokable
    public final io.qt.core.@NonNull QStringList elementSlot(){
        return elementSlot_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QStringList elementSlot_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomSlots::<wbr/>read(QXmlStreamReader&amp;)</code></p>
     */
    @QtUninvokable
    public final void read(io.qt.core.@StrictNonNull QXmlStreamReader reader){
        java.util.Objects.requireNonNull(reader, "Argument 'reader': null not expected.");
        read_native_ref_QXmlStreamReader(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(reader));
    }
    
    @QtUninvokable
    private native void read_native_ref_QXmlStreamReader(long __this__nativeId, long reader);
    
    /**
     * <p>See <code>DomSlots::<wbr/>setElementSignal(QStringList)</code></p>
     */
    @QtUninvokable
    public final void setElementSignal(java.util.@NonNull Collection<java.lang.@NonNull String> a){
        setElementSignal_native_cref_QStringList(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @QtUninvokable
    private native void setElementSignal_native_cref_QStringList(long __this__nativeId, java.util.Collection<java.lang.String> a);
    
    /**
     * <p>See <code>DomSlots::<wbr/>setElementSlot(QStringList)</code></p>
     */
    @QtUninvokable
    public final void setElementSlot(java.util.@NonNull Collection<java.lang.@NonNull String> a){
        setElementSlot_native_cref_QStringList(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @QtUninvokable
    private native void setElementSlot_native_cref_QStringList(long __this__nativeId, java.util.Collection<java.lang.String> a);
    
    /**
     * <p>See <code>DomSlots::<wbr/>write(QXmlStreamWriter&amp;,<wbr/>QString)const</code></p>
     */
    @QtUninvokable
    public final void write(io.qt.core.@StrictNonNull QXmlStreamWriter writer, java.lang.@NonNull String tagName){
        java.util.Objects.requireNonNull(writer, "Argument 'writer': null not expected.");
        write_native_ref_QXmlStreamWriter_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(writer), tagName);
    }
    
    @QtUninvokable
    private native void write_native_ref_QXmlStreamWriter_cref_QString_constfct(long __this__nativeId, long writer, java.lang.String tagName);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected DomSlots(QPrivateConstructor p) { super(p); } 
    
    
    /**
     * <p>Overloaded function for {@link #write(io.qt.core.QXmlStreamWriter, java.lang.String)}
     *  with <code>tagName = (String)null</code>.</p>
     */
    @QtUninvokable
    public final void write(io.qt.core.@StrictNonNull QXmlStreamWriter writer) {
        write(writer, (String)null);
    }
}
